@@ -1,11 +1,11 @@
-sym.interval.pc.2.j <- function(sym.data, method = c("vertex", "centers"), maxit, plot, 
+sym.interval.pc.2.j <- function(sym.data, method = c("vertex", "centers"), maxit, plot,
     scale, center) {
     idn <- all(sym.data$sym.var.types == sym.data$sym.var.types[1])
-    if (idn == FALSE) 
+    if (idn == FALSE)
         stop("All variables have to be of the same type")
     method <- match.arg(method)
-    if ((sym.data$sym.var.types[1] != "$C") && (sym.data$sym.var.types[1] != "$I")) 
-        stop("Variables have to be continuos or Interval") else if (sym.data$sym.var.types[1] == "$C") 
+    if ((sym.data$sym.var.types[1] != "$C") && (sym.data$sym.var.types[1] != "$I"))
+        stop("Variables have to be continuos or Interval") else if (sym.data$sym.var.types[1] == "$C")
         res <- principal.curve(sym.data$data, plot.true = plot, maxit = maxit) else if (sym.data$sym.var.types[1] == "$I") {
         vertex <- vertex.interval(sym.data)
         individuals <- scale(as.matrix(vertex$vertex), scale = scale, center = center)
@@ -37,7 +37,7 @@ sym.interval.pc.2.j <- function(sym.data, method = c("vertex", "centers"), maxit
             res.var.mid <- variance.princ.curve(data = as.matrix(centers), curve = res$s)
             res.var <- list(res.var.ind = res.var.ind, res.var.mid = res.var.mid)
             colnames(projection.matrix) <- sym.data$sym.var.names
-            res.limits <- sym.interval.pc.limits.2.j(sym.data = sym.data, prin.curve = projection.matrix, 
+            res.limits <- sym.interval.pc.limits.2.j(sym.data = sym.data, prin.curve = projection.matrix,
                 num.vertex = vertex$num.vertex, lambda = lambda)
             num.vars <- sym.data$M
             variables <- rep("X", num.vars)
@@ -51,20 +51,20 @@ sym.interval.pc.2.j <- function(sym.data, method = c("vertex", "centers"), maxit
         } else if (method == "vertex") {
             res <- principal.curve(individuals, plot.true = plot, maxit = maxit)
             res.var <- variance.princ.curve(data = individuals, curve = res$s)
-            res.limits <- sym.interval.pc.limits.2.j(sym.data = sym.data, prin.curve = res$s, 
+            res.limits <- sym.interval.pc.limits.2.j(sym.data = sym.data, prin.curve = res$s,
                 num.vertex = vertex$num.vertex, lambda = res$lambda)
-            
+
             num.vars <- sym.data$M
             variables <- rep("X", num.vars)
             for (i in 1:num.vars) {
-                # variables[res.var$var.order[i]] <- paste0('prin_surface_', as.character(i))
+                 variables[res.var$var.order[i]] <- paste0('prin_surface_', as.character(i))
                 variables[i] <- paste0("prin_surface_", as.character(i))
             }
             colnames(res$s) <- variables
-            # res$s <- res$s[, res.var$var.order]
+             res$s <- res$s[, res.var$var.order]
             correl <- cor(x = res$s, y = vertex$vertex)
         }
-        return(list(prin.curve = res, sym.prin.curve = res.limits, var.curve = res.var, 
+        return(list(prin.curve = res, sym.prin.curve = res.limits, var.curve = res.var,
             cor.ps = correl))
     }
     return(TRUE)
